<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:cdf="http://checklists.nist.gov/xccdf/1.1" xmlns:xccdf_12="http://checklists.nist.gov/xccdf/1.2" version="1.0">
  <xsl:output method="xml" encoding="UTF-8"/>
  <xsl:template match="/">
        <benchmark-resume>
            <xsl:apply-templates select="*[local-name()='Benchmark']"/>
        </benchmark-resume>
    </xsl:template>
  <xsl:template match="cdf:Benchmark">
        <xsl:copy-of select="@id"/>
        <xsl:attribute name="version">
            <xsl:value-of select="normalize-space(cdf:version/text())"/>
        </xsl:attribute>

        <xsl:variable name="profileId" select="cdf:TestResult[1]/cdf:profile/@idref"/>
        <xsl:choose>
            <xsl:when test="not($profileId)"/> <!-- Do not send profile element when scanning with 'default' profile. -->
            <xsl:when test="cdf:Profile[@id = $profileId]">
                <xsl:apply-templates select="cdf:Profile[@id = $profileId]"/>
            </xsl:when>
            <xsl:otherwise>
                <profile title="Tailored profile">
                    <xsl:attribute name="id">
                         <xsl:value-of select="$profileId"/>
                    </xsl:attribute>
                </profile>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="cdf:TestResult[1]"/>
    </xsl:template>
  <xsl:template match="cdf:Profile">
        <profile>
            <xsl:attribute name="title">
                <xsl:value-of select="normalize-space(cdf:title/text())"/>
            </xsl:attribute>
            <xsl:copy-of select="@id"/>
            <xsl:attribute name="description">
                <xsl:value-of select="normalize-space(cdf:description[@xml:lang='en-US']/text())"/>
            </xsl:attribute>
        </profile>
    </xsl:template>
  <xsl:template match="cdf:TestResult">
        <TestResult>
            <xsl:copy-of select="@id"/>
            <xsl:copy-of select="@start-time"/>
            <xsl:copy-of select="@end-time"/>
            <pass>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'pass']"/>
            </pass>
            <fail>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'fail']"/>
            </fail>
            <error>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'error']"/>
            </error>
            <unknown>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'unknown']"/>
            </unknown>
            <notapplicable>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'notapplicable']"/>
            </notapplicable>
            <notchecked>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'notchecked']"/>
            </notchecked>
            <notselected>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'notselected']"/>
            </notselected>
            <informational>
                   <xsl:apply-templates select="cdf:rule-result[cdf:result = 'informational']"/>
            </informational>
            <fixed>
                    <xsl:apply-templates select="cdf:rule-result[cdf:result = 'fixed']"/>
            </fixed>
        </TestResult>
    </xsl:template>
  <xsl:template match="cdf:rule-result">
        <rr>
            <xsl:attribute name="id">
                <xsl:value-of select="normalize-space(@idref)"/>
            </xsl:attribute>
            <xsl:apply-templates select="cdf:ident"/>
        </rr>
    </xsl:template>
  <xsl:template match="cdf:ident">
        <ident>
            <xsl:copy-of select="@system"/>
            <xsl:value-of select="normalize-space(text())"/>
        </ident>
    </xsl:template>
  <xsl:template match="xccdf_12:Benchmark">
        <xsl:copy-of select="@id"/>
        <xsl:attribute name="version">
            <xsl:value-of select="normalize-space(xccdf_12:version/text())"/>
        </xsl:attribute>

        <xsl:variable name="profileId" select="xccdf_12:TestResult[1]/xccdf_12:profile/@idref"/>
        <xsl:choose>
            <xsl:when test="not($profileId)"/> <!-- Do not send profile element when scanning with 'default' profile. -->
            <xsl:when test="cdf:Profile[@id = $profileId]">
                <xsl:apply-templates select="xccdf_12:Profile[@id = $profileId]"/>
            </xsl:when>
            <xsl:otherwise>
                <profile title="Tailored profile">
                    <xsl:attribute name="id">
                         <xsl:value-of select="$profileId"/>
                    </xsl:attribute>
                </profile>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="xccdf_12:TestResult[1]"/>
    </xsl:template>
  <xsl:template match="xccdf_12:Profile">
        <profile>
            <xsl:attribute name="title">
                <xsl:value-of select="normalize-space(xccdf_12:title/text())"/>
            </xsl:attribute>
            <xsl:copy-of select="@id"/>
            <xsl:attribute name="description">
                <xsl:value-of select="normalize-space(xccdf_12:description[@xml:lang='en-US']/text())"/>
            </xsl:attribute>
        </profile>
    </xsl:template>
  <xsl:template match="xccdf_12:TestResult">
        <TestResult>
            <xsl:copy-of select="@id"/>
            <xsl:copy-of select="@start-time"/>
            <xsl:copy-of select="@end-time"/>
            <pass>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'pass']"/>
            </pass>
            <fail>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'fail']"/>
            </fail>
            <error>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'error']"/>
            </error>
            <unknown>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'unknown']"/>
            </unknown>
            <notapplicable>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'notapplicable']"/>
            </notapplicable>
            <notchecked>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'notchecked']"/>
            </notchecked>
            <notselected>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'notselected']"/>
            </notselected>
            <informational>
                   <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'informational']"/>
            </informational>
            <fixed>
                    <xsl:apply-templates select="xccdf_12:rule-result[xccdf_12:result = 'fixed']"/>
            </fixed>
        </TestResult>
    </xsl:template>
  <xsl:template match="xccdf_12:rule-result">
        <rr>
            <xsl:attribute name="id">
                <xsl:value-of select="normalize-space(@idref)"/>
            </xsl:attribute>
            <xsl:apply-templates select="xccdf_12:ident"/>
        </rr>
    </xsl:template>
  <xsl:template match="xccdf_12:ident">
        <ident>
            <xsl:copy-of select="@system"/>
            <xsl:value-of select="normalize-space(text())"/>
        </ident>
    </xsl:template>
</xsl:stylesheet>
